@@ -3,7 +3,9 @@
 # Distributed under the terms of "New BSD License", see the LICENSE file.
 
 from __future__ import print_function
+from typing import List, Optional
 
+import matplotlib.pyplot as plt
 import numpy as np
 import scipy.constants
 import scipy.integrate
@@ -291,6 +293,26 @@ class DebyeModel(object):
         atoms_per_cell = len(self._murnaghan.structure)
         return atoms_per_cell * val
 
+    @property
+    def publication(self):
+        return {
+            "debye_model": {
+                "Moruzzi1988": {
+                    "title": "Calculated thermal properties of metals",
+                    "author": ["Moruzzi, V. L.", "Janak, J. F.", "Schwarz, K"],
+                    "journal": "Phys. Rev. B",
+                    "volume": "37",
+                    "issue": "2",
+                    "pages": "790--799",
+                    "numpages": "0",
+                    "month": "jan",
+                    "publisher": "American Physical Society",
+                    "doi": "10.1103/PhysRevB.37.790",
+                    "url": "https://link.aps.org/doi/10.1103/PhysRevB.37.790",
+                }
+            }
+        }
+
 
 class MurnaghanJobGenerator(JobGenerator):
     @property
@@ -613,7 +635,7 @@ class Murnaghan(AtomisticParallelMaster):
             job_name:
         """
         super(Murnaghan, self).__init__(project, job_name)
-        self.__name__ = "Murnaghan"
+
         self.__version__ = "0.3.0"
 
         # print ("h5_path: ", self.project_hdf5._h5_path)
@@ -637,6 +659,21 @@ class Murnaghan(AtomisticParallelMaster):
         self._debye_T = None
         self._job_generator = MurnaghanJobGenerator(self)
 
+    def convergence_check(self) -> bool:
+        """
+        Checks if the Murnaghan job has cnverged or not
+
+        Note: Currently, a 3rd order polynomial is fit to check if there is any convergence
+
+        Returns:
+            bool: True if the calculation is converged
+        """
+        if super().convergence_check():
+            e_vol = self["output/equilibrium_volume"]
+            return e_vol is not None
+        else:
+            return False
+
     @property
     def fit(self):
         return self.debye_model
@@ -773,15 +810,34 @@ class Murnaghan(AtomisticParallelMaster):
         else:
             self._fit_eos_general(fittype=self.input["fit_type"])
 
-    def plot(self, num_steps=100, plt_show=True, ax=None, plot_kwargs=None):
+    def plot(
+        self,
+        per_atom: bool = False,
+        num_steps: int = 100,
+        plt_show: bool = True,
+        ax=None,
+        plot_kwargs: Optional[dict] = None,
+    ):
+        """
+        Plot E-V curve.
+
+        Args:
+            per_atom (optional, bool): normalize energy and volume by number of atoms in structure before plotting
+            num_steps (optional, int): number of sample points to interpolate the calculated values on
+            plt_show (optional, bool): call `matplotlib.pyplot.show()` after plotting (only necessary when running pyiron from scripts)
+            ax (optional, plt.Axes): if given plot onto this axis, otherwise create new figure for the plot
+            plot_kwargs (optional, dict): arguments passed verbatim to `matplotlib.pyplot.plot()`
+
+        Returns:
+            ax: The axis plotted onto
+
+        Raises:
+            ValueError: if job is not finished when calling this method
+        """
         if not self.status.finished:
             raise ValueError(
                 "Job must be successfully run, before calling this method."
             )
-        try:
-            import matplotlib.pylab as plt
-        except ImportError:
-            import matplotlib.pyplot as plt
 
         if ax is None:
             ax = plt.subplot(111)
@@ -814,14 +870,15 @@ class Murnaghan(AtomisticParallelMaster):
         else:
             label = self.input["fit_type"]
 
+        normalization = 1 if not per_atom else len(self.structure)
         if self.fit_dict is not None:
             if self.input["fit_type"] == "polynomial":
                 p_fit = np.poly1d(self.fit_dict["poly_fit"])
                 least_square_error = self.fit_module.get_error(vol_lst, erg_lst, p_fit)
                 ax.set_title("Murnaghan: error: " + str(least_square_error))
                 ax.plot(
-                    x_i,
-                    p_fit(x_i),
+                    x_i / normalization,
+                    p_fit(x_i) / normalization,
                     "-",
                     label=label,
                     color=color,
@@ -837,8 +894,8 @@ class Murnaghan(AtomisticParallelMaster):
                     parameters=[E0, B0, BP, V0], vol=x_i, fittype=self.input["fit_type"]
                 )
                 ax.plot(
-                    x_i,
-                    eng_fit_lst,
+                    x_i / normalization,
+                    eng_fit_lst / normalization,
                     "-",
                     label=label,
                     color=color,
@@ -846,7 +903,14 @@ class Murnaghan(AtomisticParallelMaster):
                     **plot_kwargs,
                 )
 
-        ax.plot(vol_lst, erg_lst, "x", color=color, markersize=20, **plot_kwargs)
+        ax.plot(
+            vol_lst / normalization,
+            erg_lst / normalization,
+            "x",
+            color=color,
+            markersize=20,
+            **plot_kwargs,
+        )
         ax.legend()
         ax.set_xlabel("Volume ($\AA^3$)")
         ax.set_ylabel("energy (eV)")
