@@ -15,6 +15,7 @@ from pyiron_base import (
     JobTypeChoice,
     Project as ProjectCore,
     Creator as CreatorCore,
+    deprecate,
 )
 
 try:
@@ -51,7 +52,17 @@ if not (isinstance(ase.__file__, str)):
 
 class Project(ProjectCore):
     """
-    The project is the central class in pyiron, all other objects can be created from the project object.
+    Welcome to pyiron! The project is the central class in pyiron, all other objects can be
+    created from the project object.
+
+    Your first steps in pyiron:
+
+    >>> pr = Project("EXAMPLE")
+    >>> job = pr.create.job.Lammps(job_name="lmp_example")
+
+    Replace `Lammps` by the job type of your choice - you can look at the list of all available
+    jobs in the list of auto-complete in `pr.create.job`. After you create a job, look up the
+    DocString of your job by `job?` to find out what are the next steps!
 
     Args:
         path (GenericPath, str): path of the project defined by GenericPath, absolute or relative (with respect to
@@ -439,6 +450,7 @@ class Project(ProjectCore):
 
     # Deprecated methods
 
+    @deprecate("Use create.struture.bulk instead")
     def create_ase_bulk(
         self,
         name,
@@ -468,10 +480,6 @@ class Project(ProjectCore):
 
             pyiron.atomistics.structure.atoms.Atoms: Required bulk structure
         """
-        # warnings.warn(
-        #     "Project.create_ase_bulk is deprecated as of v0.3. Please use Project.create.structure.ase_bulk.",
-        #     DeprecationWarning
-        # )
         return self.create.structure.ase.bulk(
             name=name,
             crystalstructure=crystalstructure,
@@ -483,6 +491,7 @@ class Project(ProjectCore):
             cubic=cubic,
         )
 
+    @deprecate("Use create.struture.* methods instead")
     def create_structure(self, element, bravais_basis, lattice_constant):
         """
         Create a crystal structure using pyiron's native crystal structure generator
@@ -506,6 +515,7 @@ class Project(ProjectCore):
             lattice_constant=lattice_constant,
         )
 
+    @deprecate("Use create.struture.surface instead")
     def create_surface(
         self,
         element,
@@ -549,6 +559,7 @@ class Project(ProjectCore):
             **kwargs
         )
 
+    @deprecate("Use create.struture.atoms instead")
     def create_atoms(
         self,
         symbols=None,
@@ -627,6 +638,7 @@ class Project(ProjectCore):
             **qwargs
         )
 
+    @deprecate("Use create.struture.element instead")
     def create_element(
         self, parent_element, new_element_name=None, spin=None, potential_file=None
     ):
